import request from '@/utils/request';

class ResourceApi {
  constructor() {
    this.basePath = '/resources';
  }

  async deleteResourceById(id) {
    try {
      return await request({
        url: `${this.basePath}/${id}`,
        method: 'DELETE'
      });
    } catch (error) {
      this.handleRequestError(error, '删除资源');
    }
  }

  async getResourceById(id) {
    try {
      return await request({
        url: `${this.basePath}/${id}`,
        method: 'GET'
      });
    } catch (error) {
      this.handleRequestError(error, '获取资源');
    }
  }

  async updateResourceById(id, data) {
    try {
      return await request({
        url: `${this.basePath}/${id}`,
        method: 'PUT',
        data
      });
    } catch (error) {
      this.handleRequestError(error, '更新资源');
    }
  }

  async getResourcesPage(page, pageSize = 12, name) {
    try {
      return await request({
        url: `${this.basePath}/page`,
        method: 'GET',
        params: { page, pageSize, name }
      });
    } catch (error) {
      this.handleRequestError(error, '获取资源分页');
    }
  }

  async uploadResource(data) {
    try {
      return await request({
        url: this.basePath,
        method: 'POST',
        data
      });
    } catch (error) {
      this.handleRequestError(error, '上传资源');
    }
  }

  handleRequestError(error, action = '请求') {
    if (error.response) {
      console.error(`${action}时服务器返回错误:`, error.response.data, `状态码: ${error.response.status}`);
    } else if (error.request) {
      console.error(`${action}时未收到服务器响应:`, error.request);
    } else {
      console.error(`${action}时发生错误:`, error.message);
    }
    throw error;
  }
}

const resourceApi = new ResourceApi();

export const deleteResourceById = (id) => resourceApi.deleteResourceById(id);
export const getResourceById = (id) => resourceApi.getResourceById(id);
export const updateResourceById = (id, data) => resourceApi.updateResourceById(id, data);
export const getResourcesPage = (page, pageSize, name) => resourceApi.getResourcesPage(page, pageSize, name);
export const uploadResource = (data) => resourceApi.uploadResource(data);

export default resourceApi;

