import request from '@/utils/request';

class TeacherApi {
  constructor() {
    this.basePath = '/teacher';
  }

  // Awards 相关方法
  async deleteAwardById(id) {
    return request({
      url: `${this.basePath}/awards/${id}`,
      method: 'DELETE'
    });
  }

  async getAwardById(id) {
    return request({
      url: `${this.basePath}/awards/${id}`,
      method: 'GET'
    });
  }

  async updateAwardById(id, data) {
    return request({
      url: `${this.basePath}/awards/${id}`,
      method: 'PUT',
      data
    });
  }

  async uploadAward(data) {
    return request({
      url: `${this.basePath}/awards`,
      method: 'POST',
      data
    });
  }

  // Teachers 相关方法
  async deleteTeacherById(id) {
    return request({
      url: `${this.basePath}/${id}`,
      method: 'DELETE'
    });
  }

  async getTeacherById(id) {
    return request({
      url: `${this.basePath}/${id}`,
      method: 'GET'
    });
  }

  async updateTeacherById(id, data) {
    return request({
      url: `${this.basePath}/${id}`,
      method: 'PUT',
      data
    });
  }

  async createTeacher(data) {
    return request({
      url: this.basePath,
      method: 'POST',
      data
    });
  }

  // Theses 相关方法
  async deleteThesisById(id) {
    return request({
      url: `${this.basePath}/thesis/${id}`,
      method: 'DELETE'
    });
  }

  async getThesisById(id) {
    return request({
      url: `${this.basePath}/thesis/${id}`,
      method: 'GET'
    });
  }

  async updateThesisById(id, data) {
    return request({
      url: `${this.basePath}/thesis/${id}`,
      method: 'PUT',
      data
    });
  }

  async uploadThesis(data) {
    return request({
      url: `${this.basePath}/thesis`,
      method: 'POST',
      data
    });
  }

  // Works 相关方法
  async deleteWorkById(id) {
    return request({
      url: `${this.basePath}/work/${id}`,
      method: 'DELETE'
    });
  }

  async getWorkById(id) {
    return request({
      url: `${this.basePath}/work/${id}`,
      method: 'GET'
    });
  }

  async updateWorkById(id, data) {
    return request({
      url: `${this.basePath}/work/${id}`,
      method: 'PUT',
      data
    });
  }

  async uploadWork(data) {
    return request({
      url: `${this.basePath}/work`,
      method: 'POST',
      data
    });
  }
}

const teacherApi = new TeacherApi();

export const deleteAwardById = (id) => teacherApi.deleteAwardById(id);
export const getAwardById = (id) => teacherApi.getAwardById(id);
export const updateAwardById = (id, data) => teacherApi.updateAwardById(id, data);
export const uploadAward = (data) => teacherApi.uploadAward(data);

export const deleteTeacherById = (id) => teacherApi.deleteTeacherById(id);
export const getTeacherById = (id) => teacherApi.getTeacherById(id);
export const updateTeacherById = (id, data) => teacherApi.updateTeacherById(id, data);
export const createTeacher = (data) => teacherApi.createTeacher(data);

export const deleteThesisById = (id) => teacherApi.deleteThesisById(id);
export const getThesisById = (id) => teacherApi.getThesisById(id);
export const updateThesisById = (id, data) => teacherApi.updateThesisById(id, data);
export const uploadThesis = (data) => teacherApi.uploadThesis(data);

export const deleteWorkById = (id) => teacherApi.deleteWorkById(id);
export const getWorkById = (id) => teacherApi.getWorkById(id);
export const updateWorkById = (id, data) => teacherApi.updateWorkById(id, data);
export const uploadWork = (data) => teacherApi.uploadWork(data);

export default teacherApi;