import request from '@/utils/request';

class UserApi {
  constructor() {
    this.basePath = '/user';
  }

  async userLoginPost(data) {
    return request({
      url: `${this.basePath}/login`,
      method: 'POST',
      data
    });
  }

  async userRegisterPost(data) {
    return request({
      url: `${this.basePath}/register`,
      method: 'POST',
      data
    });
  }

  async userLogoutPost(token) {
    return request({
      url: `${this.basePath}/logout`,
      method: 'POST',
      headers: { token }
    });
  }

  async userForgetPost(data) {
    return request({
      url: `${this.basePath}/forget`,
      method: 'POST',
      data
    });
  }

  async userPasswordPut(data) {
    return request({
      url: `${this.basePath}/password`,
      method: 'PUT',
      data
    });
  }

  async userDownloadGet(id, status) {
    if (typeof id !== 'number' || typeof status !== 'number') {
      throw new Error('Invalid parameters: id and status must be numbers');
    }
    return request({
      url: `${this.basePath}/download?id=${id}&status=${status}`,
      method: 'GET'
    });
  }

  async userUploadPost(file) {
    if (!(file instanceof File)) {
      throw new Error('Invalid parameter: file must be a File object');
    }

    const formData = new FormData();
    formData.append('file', file);

    return request({
      url: `${this.basePath}/upload`,
      method: 'POST',
      data: formData
    });
  }

  async getRole() {
    return request({
      url: `${this.basePath}/role`,
      method: 'GET',
    }).role
  }

  async getMe() {
    return request({
      url: `${this.basePath}/me`,
      method: `GET`,
    });
  }

}

const userApi = new UserApi();

export const userLoginPost = (data) => userApi.userLoginPost(data);
export const userRegisterPost = (data) => userApi.userRegisterPost(data);
export const userLogoutPost = (token) => userApi.userLogoutPost(token);
export const userForgetPost = (data) => userApi.userForgetPost(data);
export const userPasswordPut = (data) => userApi.userPasswordPut(data);
export const userDownloadGet = (id, status) => userApi.userDownloadGet(id, status);
export const userUploadPost = (file) => userApi.userUploadPost(file);
export const getRole = () => userApi.getRole();
export const getMe = () => userApi.getMe();

export default userApi;

