import { ref, computed } from 'vue'

export function usePagination(fetchFunction, itemsPerPage = 10) {
  const currentPage = ref(1)
  const totalPages = ref(1)

  const setPage = (page) => {
    currentPage.value = page
    fetchFunction(page)
  }

  const nextPage = () => {
    if (currentPage.value < totalPages.value) {
      setPage(currentPage.value + 1)
    }
  }

  const prevPage = () => {
    if (currentPage.value > 1) {
      setPage(currentPage.value - 1)
    }
  }

  const paginationInfo = computed(() => ({
    currentPage: currentPage.value,
    totalPages: totalPages.value,
    hasPrev: currentPage.value > 1,
    hasNext: currentPage.value < totalPages.value,
  }))

  return {
    currentPage,
    totalPages,
    setPage,
    nextPage,
    prevPage,
    paginationInfo,
  }
}