import { createRouter, createWebHistory } from 'vue-router'
import Home from '../views/Home.vue'
import Login from '../views/Login.vue'
import Register from '../views/Register.vue'
import ForgotPassword from '../views/ForgotPassword.vue'
import Profile from '../views/Profile.vue'
import EditProfile from '../views/EditProfile_.vue'
import ChangePassword from '../views/ChangePassword.vue'
import TeacherDetail from '../views/TeacherDetail.vue'
import PaperDetail from '../views/PaperDetail.vue'
import PaperUpload from '../views/PaperUpload.vue'
import SharedLibrary from '../views/SharedLibrary.vue'
import AdminAccount from '../views/AdminAccount.vue'
import AdminFileManagement from '../views/AdminFileManagement.vue'
import { useAuthStore } from '@/store/modules/auth';

const routes = [
  {
    path: '/',
    name: 'Home',
    component: Home
  },
  {
    path: '/login',
    name: 'Login',
    component: Login
  },
  {
    path: '/register',
    name: 'Register',
    component: Register
  },
  {
    path: '/forgot-password',
    name: 'ForgotPassword',
    component: ForgotPassword
  },
  {
    path: '/shared-library',
    name: 'SharedLibrary',
    component: SharedLibrary
  },
  {
    path: '/teacher/:id',
    name: 'TeacherDetail',
    component: TeacherDetail,
    props: true
  },
  {
    path: '/paper/:id',
    name: 'PaperDetail',
    component: PaperDetail,
    props: true
  },
  {
    path: '/profile',
    name: 'Profile',
    component: Profile,
    meta: { requiresAuth: true }
  },
  {
    path: '/editprofile',
    name: 'Editprofile',
    component: EditProfile,
    meta: { requiresAuth: true }
  },
  {
    path: '/change-password',
    name: 'ChangePassword',
    component: ChangePassword,
    meta: { requiresAuth: true }
  },
  {
    path: '/paper-upload',
    name: 'PaperUpload',
    component: PaperUpload,
    meta: { requiresAuth: true }
  },
  {
    path: '/admin/accounts',
    name: 'AdminAccount',
    component: AdminAccount,
    meta: { requiresAuth: true, requiresAdmin: true }
  },
  {
    path: '/admin/files',
    name: 'AdminFileManagement',
    component: AdminFileManagement,
    meta: { requiresAuth: true, requiresAdmin: true }
  }
]

const router = createRouter({
  history: createWebHistory(),
  routes
})

// Navigation guard
router.beforeEach(async (to, from, next) => {
  const authStore = useAuthStore();

  if(!authStore.user)
    await authStore.authFromLocal()
  const isAuthenticated = authStore.user != null;
  const isAdmin = authStore.user != null && authStore.user.role == 'admin'; // TODO

  
  if (to.matched.some(record => record.meta.requiresAuth)) {
    if (!isAuthenticated) {
      next({ name: 'Login', query: { redirect: to.fullPath } })
    } else if (to.matched.some(record => record.meta.requiresAdmin) && !isAdmin) {
      next({ name: 'Home' }) // Redirect non-admin users
    } else {
      next()
    }
  } else {
    next()
  }
})

export default router