import { ref } from 'vue';
import { defineStore } from 'pinia';
import { getMe, userLoginPost, userLogoutPost } from '../../api/Users';
import { userRegisterPost, userForgetPost, userPasswordPut } from '../../api/Users';

// export const useAuthStore = defineStore('auth', {
//   state: () => ({
//     user: null,
//     isAuthenticated: false,
//     isAdmin: false,
//     first: false
//   }),
//   actions: {
//     async login(username, password) {
//       try {
//         const response = await userLoginPost({ username, password });
//         this.user = response.data;
//         this.isAuthenticated = true;
//         this.isAdmin = this.user.role === 'admin';
//         return true;
//       } catch (error) {
//         this.handleError('登录失败', error);
//         return false;
//       }
//     },
//     async logout() {
//       try {
//         await userLogoutPost();
//         this.resetAuthState();
//       } catch (error) {
//         this.handleError('登出失败', error);
//       }
//     },
//     async register(userData) {
//       try {
//         await userRegisterPost(userData);
//         return true;
//       } catch (error) {
//         this.handleError('注册失败', error);
//         return false;
//       }
//     },
//     async forgotPassword(userData) {
//       try {
//         await userForgetPost(userData);
//         return true;
//       } catch (error) {
//         this.handleError('密码重置请求失败', error);
//         return false;
//       }
//     },
//     async changePassword(oldPassword, newPassword) {
//       try {
//         await userPasswordPut({ oldPassword, newPassword });
//         return true;
//       } catch (error) {
//         this.handleError('密码更改失败', error);
//         return false;
//       }
//     },
//     resetAuthState() {
//       this.user = null;
//       this.isAuthenticated = false;
//       this.isAdmin = false;
//     },
//     handleError(message, error) {
//       console.error(message, error);
//     },

//     setUser(user) {
//       this.user = user;
//       this.isAuthenticated = true;
//       this.isAdmin = user.role === 'admin';
//     },
//   },
// });


export const useAuthStore = defineStore('auth', () => {
  const user = ref(null);

  const setAuth = (token, userInfo) => {
    localStorage.setItem('token', token);
    delete userInfo.token;
    user.value = userInfo;
  };

  const authFromLocal = async () => {
    const token = localStorage.getItem('token');
    if (!token) return false;
  
    try {
      const response = await getMe();
      setAuth(token, response.data); // 在获取成功后设置 auth
      return true;
    } catch (error) {
      console.error("Error fetching user data:", error);
      return false;
    }
  };

  const getAuth = async () => {
    if(user)
      return user;
    const token = localStorage.getItem('token');
    if (!token) await authFromLocal();
    if (!token) return null;
    try {
      const response = await getMe();
      setAuth(token, response.data);
      return response.data;
    } catch (error) {
      removeAuth(); // 如果出错，清除无效 token
      return null;
    }
  };

  const removeAuth = () => {
    localStorage.removeItem('token');
    user.value = null;
  };

  return {
    user,
    setAuth,
    getAuth,
    authFromLocal,
    removeAuth,
  };
});
