import { defineStore } from 'pinia'
import * as OpenApi from '../../api/Open'
import * as TeacherApi from '../../api/Teacher'

export const useTeachersStore = defineStore('teachers', {
  state: () => ({
    teachers: [],
    currentTeacher: null,
    totalPages: 1,
    currentPage: 1,
    isLoading: false,
    error: null,
  }),
  getters: {
    isLastPage: (state) => state.currentPage === state.totalPages,
  },
  actions: {
    async fetchTeachers(page = 1, pageSize = 12, name = '') {
      this.isLoading = true
      this.error = null
      try {
        const response = await OpenApi.default.getHomepageData(page, pageSize = 12, name)
        this.teachers = response.data.records
        this.total = response.data.total
        this.currentPage = page
      } catch (error) {
        console.error('获取教师列表失败:', error)
        this.error = '获取教师列表失败。请重试。'
      } finally {
        this.isLoading = false
      }
    },
    async fetchTeacherDetails(id) {
      this.isLoading = true
      this.error = null
      try {
        const response = await TeacherApi.getTeacherById(id)
        this.currentTeacher = response.data
      } catch (error) {
        console.error('获取教师详情失败:', error)
        this.error = '获取教师详情失败。请重试。'
      } finally {
        this.isLoading = false
      }
    },
    async updateTeacherProfile(id, profileData) {
      this.isLoading = true
      this.error = null
      try {
        const updatedTeacher = await TeacherApi.updateProfile(id, profileData)
        if (this.currentTeacher && this.currentTeacher.id === id) {
          this.currentTeacher = updatedTeacher
        }
        const index = this.teachers.findIndex(t => t.id === id)
        if (index !== -1) {
          this.teachers[index] = updatedTeacher
        }
      } catch (error) {
        console.error('Failed to update teacher profile:', error)
        this.error = 'Failed to update teacher profile. Please try again.'
      } finally {
        this.isLoading = false
      }
    },
    
  },
})