import axios from 'axios'
import { useAuthStore } from '@/store/modules/auth';

const request = axios.create({
  // baseURL: import.meta.env.VITE_APP_API_BASE_URL, // 使用环境变量设置基础URL
  baseURL: '/api', // 使用环境变量设置基础URL
  timeout: 5000,
})

request.interceptors.request.use(
  (config) => {
    const token = localStorage.getItem("token");
    if (token) {
      config.headers['token'] = token // 修改为 'token'，而不是 'Authorization'
    }
    return config
  },
  (error) => {
    return Promise.reject(error)
  }
)

request.interceptors.response.use(
  (response) => response.data, // 直接返回响应的数据部分
  (error) => {
    if (error.response && error.response.status === 401) {
      // 处理未授权访问（例如，重定向到登录页面）
      console.log('Unauthorized access, redirecting to login...')
      // 这里可以添加重定向逻辑
    }
    return Promise.reject(error)
  }
)

export default request